/*
 * libspe - A wrapper library to adapt the JSRE SPU usage model to SPUFS
 * Copyright (C) 2005 IBM Corp.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License,
 * or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 *  License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License
 *   along with this library; if not, write to the Free Software Foundation,
 *   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/* ===========================================================================
 * mfc function wrappers in spe library are defined here.
 */

/* FUNCTION:    _put_mfc_outbox (spe_ps_addr, val)
 *
 * Send value to the PPE->SPE mailbox WITHOUT first checking to make sure the
 * PPE->SPE mailbox queue is NOT FULL.  If the queue is full, this would result
 * in an OVERWRITE of the last mailbox value sent.
 */
extern int _put_mfc_outbox (void *spe_ps_addr ,unsigned int data);

/* FUNCTION:    _stat_mfc_outbox (spe_ps_addr)
 *
 * Returns the status of the PE->SPE mailbox.
 */
extern int _stat_mfc_outbox (void *spe_ps_addr);

/* FUNCTION:    _get_mfc_inbox (spe_ps_addr)
 *
 * Return the contents of the SPE->PPE mailbox without first checking to see
 * if a new mailbox value is present.  This allows for re-read of this
 * register.
 */
extern int _get_mfc_inbox (void *spe_ps_addr);

/* FUNCTION:    _stat_mfc_inbox (spe_ps_addr)
 *
 * Returns the status of the SPE->PE mailbox.
 */
extern int _stat_mfc_inbox (void *spe_ps_addr);

/* FUNCTION:    _stat_mfc_inbox_intr (spe_ps_addr)
 *
 * Returns the status of the SPE->PPE interrupting mailbox.
 */
extern int _stat_mfc_inbox_intr (void *spe_ps_addr);

/* FUNCTION:    _send_mfc_sig (spe_ps_addr, signal_reg, data)
 *
 * Write the data word to the specified SPE signal notification register.
 */
extern int _send_mfc_sig (void *spe_ps_addr, unsigned int signal_reg, unsigned int data);
