/*
 * libspe - A wrapper library to adapt the JSRE SPE usage model to SPUFS 
 * Copyright (C) 2005 IBM Corp. 
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by 
 * the Free Software Foundation; either version 2.1 of the License, 
 * or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful, but 
 *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 *  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
 *  License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License 
 *   along with this library; if not, write to the Free Software Foundation, 
 *   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef _spe_h_
#define _spe_h_

typedef void *speid_t;
typedef void *spe_gid_t;

typedef struct {
        void		*start;
        void		*toe_struct;
        unsigned int    prog_size;
} spe_program_handle_t;

/* Flags for spe_create_thread
 */

#define SPE_PTRACE_ME		  0x0001	/* Allow debugger to attach   */
#define SPE_USER_REGS		  0x0002	/* 128b user data for r3-5.   */

#define SPE_CFG_SIGNOTIFY1_OR     0x00000010
#define SPE_CFG_SIGNOTIFY2_OR     0x00000020

/* Flags for 
 * */
#define SPE_MAX_THREADS_PER_GROUP     16	/* Sanity value - will be removed in the future */

/* Low-level SPE execution API.
 */
extern void *spe_gid_setup(int policy, int priority, int use_events);
extern void *spe_setup (spe_gid_t gid, spe_program_handle_t *handle, void *argp, void *envp, int flags);
extern void spe_cleanup (void *spe);
extern int do_spe_run (void *spe);
extern unsigned int set_npc (void *spe, unsigned int npc);

/* APIs for SPE threads.
 */

extern spe_gid_t spe_create_group (int policy, int priority, int spe_events);
extern int spe_group_max (spe_gid_t spe_gid);

extern speid_t spe_create_thread (spe_gid_t gid, spe_program_handle_t *handle,
				  void *argp, void *envp,
				  unsigned long mask, int flags);

extern int spe_wait (speid_t speid, int *status, int options);

extern int spe_kill (speid_t speid, int sig);
extern int spe_get_priority(spe_gid_t gid);
extern int spe_set_priority(spe_gid_t gid, int priority);
extern int spe_get_policy(spe_gid_t gid);
extern spe_gid_t spe_get_group (speid_t speid);
extern int spe_group_defaults(int policy, int priority, int spe_events);
	
extern void *spe_get_ls(speid_t speid);
extern void *spe_get_ps(speid_t speid);

/* APIs for loading SPE images
 */
extern spe_program_handle_t *spe_open_image(const char *filename);
extern int spe_close_image(spe_program_handle_t *program_handle);

#endif
